@@ -1,9 +1,9 @@
 import os
 
-from django import template
 from django.core.management.base import AppCommand
 
 from utils_plus.utils.misc import read_if_exists
+from .create_admin import render_template
 
 CLASS_TMPL = """\
 
@@ -29,8 +29,7 @@ class Command(AppCommand):
         mware_name = "{}_middleware".format(options['name'])
 
         if mware_name not in content:
-            tmpl = template.Template(CLASS_TMPL)
-            content += tmpl.render(template.Context(dict(name=mware_name)))
+            content += render_template(CLASS_TMPL, name=mware_name)
 
         # finaly write file contents
         if content:
